##
##  apache-mono.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2015 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         apache-mono
Summary:      Apache Extension: Mono Adapter
URL:          https://github.com/mono/mod_mono/
Vendor:       D.L. Ridruejo, G.P. Javuer, J. Tauberer, M. Habersack
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      Apache
Version:      3.12
Release:      20150221

#   list of sources
Source0:      https://github.com/mono/mod_mono/archive/%{version}.tar.gz
Source1:      apache-mono.conf
Patch0:       apache-mono.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20140101, autoconf, automake, libtool
PreReq:       OpenPKG, openpkg >= 20140101, mono-xsp
BuildPreReq:  apache, apr
PreReq:       apache, apr

%description
    Apache Mono adapter is a glue code between the Apache HTTP server
    and Mono. This package contains the mod_mono connector module for
    Apache.

%track
    prog apache-mono = {
        version   = %{version}
        url       = https://github.com/mono/mod_mono/releases
        regex     = (\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n mod_mono-%{version}
    %patch -p0

%build
    #   configure DSO
    sh autogen.sh
    CC="`%{l_prefix}/sbin/apxs -q CC`" \
    CFLAGS="`%{l_prefix}/sbin/apxs -q CFLAGS`" \
    ./configure \
        --prefix=%{l_prefix} \
        --with-apxs=%{l_prefix}/sbin/apxs \
        --with-mono-default-config-dir=%{l_prefix}/etc/apache-mono \
        --with-mono-prefix=%{l_prefix}

    #   build DSO
    %{l_make} %{l_mflags}

%install
    #   create installation tree
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache-mono \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/apache \
        $RPM_BUILD_ROOT%{l_prefix}/var/apache-mono \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8

    #   install config
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE apache-mono.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d/

    #   install mod_mono DSO and manpage
    %{l_shtool} install -c -m 755 \
        src/.libs/mod_mono.so \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/apache/mod_mono.so
    %{l_shtool} install -c -m 644 \
        man/mod_mono.8 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/apache/apache.d/apache-mono.conf'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} apache status 2>/dev/null`
    [ ".$apache_active" = .yes ] && %{l_rc} apache restart
    exit 0

